@@ -1,4 +1,4 @@
-"""Miscellaneous tools for marine carbonate chemistry and other delights."""
+"""Miscellaneous tools for marine carbonate chemistry and other such things."""
 
 import string, textwrap
 import numpy as np
@@ -6,7 +6,7 @@ from . import crm, infrared, molar, spectro, vindta
 
 __all__ = ["crm", "infrared", "molar", "spectro", "vindta"]
 
-__version__ = "0.0.3"
+__version__ = "0.0.4"
 
 
 lcletter = dict(zip(range(1, 27), string.ascii_lowercase))
@@ -21,23 +21,14 @@ def sigfig(x, sf):
 def say_hello():
     greeting = textwrap.dedent(
         r"""
-        ┌────────────────────────────┐
-
-           ┬┌─┌─┐┌─┐┬  ┌─┐┌┬┐┌─┐┌─┐
-           ├┴┐│ ││ ││  └─┐ │ │ │├┤ 
-           ┴ ┴└─┘└─┘┴─┘└─┘ ┴ └─┘└  
-        
-          Miscellaneous tools for
-          marine carbonate chemistry
-          and other delights
-        
-          Matthew P. Humphreys
-          https://mvdh.xyz
-        
-          Version {}
-
-
-        └────────────────────────────┘
+        k  Miscellaneous tools for
+        o  marine carbonate chemistry
+        o  and other such things
+        l  
+        s  Matthew P. Humphreys
+        t  https://mvdh.xyz
+        o  
+        f  Version {}
         """.format(
             __version__
         )
